solation Forest (孤立森林) - 最受欢迎

核心思想
"异常点很容易被孤立" - 通过随机切分，异常点平均只需要很少的切分次数就能被隔离。

正常数据需要多次切分：        异常数据很快被隔离：
    ┌─────────────┐              ┌─────────────┐
    │ x x x x x x │              │ x x x x   o │
    │ x x x x x x │              │ x x x x     │
    │ x x x x x x │              │ x x x x     │
    └─────────────┘              └─────────────┘
         ↓ 切分5次                    ↓ 切分1次
    ┌───┬───┬───┐                ┌─────────┬───┐
    │ x │ x │ x │                │ x x x x │ o │
    └───┴───┴───┘                └─────────┴───┘


为什么Isolation Forest这么流行？

不需要距离计算：比基于距离的方法快很多
线性时间复杂度：O(n log n)
对维度不敏感：高维数据表现依然很好
内存友好：只需要存储树结构